@@ -415,7 +415,7 @@ class fock_space_kron:
             sparse matrix
         """
         if (i<self.f1.modes):
-             return(sparse.kron(f1.sigmax(i), self.f2.eye))
+             return(sparse.kron(self.f1.sigmax(i), self.f2.eye))
         else:
             return(sparse.kron(self.f1.eye, self.f2.sigmax(i-self.f1.modes)))
 
